@@ -72,7 +72,7 @@ impl LeetCode {
             .conf
             .sys
             .urls
-            .get("problems")?
+            .get("problems").ok_or(Error::NoneError)?
             .replace("$category", category);
 
         Req {
@@ -90,10 +90,10 @@ impl LeetCode {
 
     pub async fn get_question_ids_by_tag(self, slug: &str) -> Result<Response, Error> {
         trace!("Requesting {} ref problems...", &slug);
-        let url = &self.conf.sys.urls.get("graphql")?;
+        let url = &self.conf.sys.urls.get("graphql").ok_or(Error::NoneError)?;
         let mut json: Json = HashMap::new();
         json.insert("operationName", "getTopicTag".to_string());
-        json.insert("variables", r#"{"slug": "$slug"}"#.replace("$slug", &slug));
+        json.insert("variables", r#"{"slug": "$slug"}"#.replace("$slug", slug));
         json.insert(
             "query",
             vec![
@@ -110,7 +110,7 @@ impl LeetCode {
 
         Req {
             default_headers: self.default_headers,
-            refer: Some((&self.conf.sys.urls.get("tag")?).replace("$slug", slug)),
+            refer: Some((self.conf.sys.urls.get("tag").ok_or(Error::NoneError)?).replace("$slug", slug)),
             info: false,
             json: Some(json),
             mode: Mode::Post,
@@ -124,7 +124,7 @@ impl LeetCode {
     /// Get specific problem detail
     pub async fn get_question_detail(self, slug: &str) -> Result<Response, Error> {
         trace!("Requesting {} detail...", &slug);
-        let refer = self.conf.sys.urls.get("problems")?.replace("$slug", slug);
+        let refer = self.conf.sys.urls.get("problems").ok_or(Error::NoneError)?.replace("$slug", slug);
         let mut json: Json = HashMap::new();
         json.insert(
             "query",
@@ -147,7 +147,7 @@ impl LeetCode {
 
         json.insert(
             "variables",
-            r#"{"titleSlug": "$titleSlug"}"#.replace("$titleSlug", &slug),
+            r#"{"titleSlug": "$titleSlug"}"#.replace("$titleSlug", slug),
         );
 
         json.insert("operationName", "getQuestionDetail".to_string());
@@ -184,7 +184,7 @@ impl LeetCode {
     /// Get the result of submission / testing
     pub async fn verify_result(self, id: String) -> Result<Response, Error> {
         trace!("Verifying result...");
-        let url = self.conf.sys.urls.get("verify")?.replace("$id", &id);
+        let url = self.conf.sys.urls.get("verify").ok_or(Error::NoneError)?.replace("$id", &id);
         Req {
             default_headers: self.default_headers,
             refer: None,
